#
# spec file for package kdeplasma6-addons
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.5.0
%define qt6_version 6.7.0

%define rname kdeplasma-addons
# Full Plasma 6 version (e.g. 6.0.0)
%{!?_plasma6_bugfix: %define _plasma6_bugfix %{version}}
# Latest ABI-stable Plasma (e.g. 6.0 in KF6, but 6.0.80 in KUF)
%{!?_plasma6_version: %define _plasma6_version %(echo %{_plasma6_bugfix} | awk -F. '{print $1"."$2}')}
%bcond_without released
Name:           kdeplasma6-addons
Version:        6.2.5
Release:        1.1
Summary:        Additional Plasma6 Widgets
License:        GPL-2.0-or-later AND LGPL-2.1-only AND GPL-3.0-only
URL:            https://www.kde.org/
Source:         https://download.kde.org/stable/plasma/%{version}/%{rname}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/plasma/%{version}/%{rname}-%{version}.tar.xz.sig
Source2:        plasma.keyring
%endif
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  pkgconfig
BuildRequires:  cmake(KF6Auth) >= %{kf6_version}
BuildRequires:  cmake(KF6Config) >= %{kf6_version}
BuildRequires:  cmake(KF6CoreAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6DBusAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6Declarative) >= %{kf6_version}
BuildRequires:  cmake(KF6GlobalAccel) >= %{kf6_version}
BuildRequires:  cmake(KF6Holidays) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KF6JobWidgets) >= %{kf6_version}
BuildRequires:  cmake(KF6KCMUtils) >= %{kf6_version}
BuildRequires:  cmake(KF6KIO) >= %{kf6_version}
BuildRequires:  cmake(KF6NewStuff) >= %{kf6_version}
BuildRequires:  cmake(KF6Notifications) >= %{kf6_version}
BuildRequires:  cmake(KF6Runner) >= %{kf6_version}
BuildRequires:  cmake(KF6Service) >= %{kf6_version}
BuildRequires:  cmake(KF6Sonnet) >= %{kf6_version}
BuildRequires:  cmake(KF6UnitConversion) >= %{kf6_version}
BuildRequires:  cmake(KF6XmlGui) >= %{kf6_version}
BuildRequires:  cmake(Plasma) >= %{_plasma6_bugfix}
BuildRequires:  cmake(Plasma5Support) >= %{_plasma6_bugfix}
BuildRequires:  cmake(PlasmaQuick) >= %{_plasma6_bugfix}
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6Core5Compat) >= %{qt6_version}
BuildRequires:  cmake(Qt6DBus) >= %{qt6_version}
BuildRequires:  cmake(Qt6Gui) >= %{qt6_version}
BuildRequires:  cmake(Qt6Network) >= %{qt6_version}
BuildRequires:  cmake(Qt6Qml) >= %{qt6_version}
BuildRequires:  cmake(Qt6Quick) >= %{qt6_version}
BuildRequires:  cmake(Qt6Test) >= %{qt6_version}
%ifarch x86_64 aarch64 riscv64
BuildRequires:  cmake(Qt6WebEngineQuick) >= %{qt6_version}
%endif
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
BuildRequires:  pkgconfig(icu-i18n)
BuildRequires:  pkgconfig(icu-uc)
Requires:       kf6-kitemmodels-imports >= %{kf6_version}
Requires:       kf6-purpose >= %{kf6_version}
Requires:       kirigami-addons6
Provides:       plasma-addons = %{version}
Obsoletes:      plasma-addons < %{version}
Provides:       plasma5-addons = %{version}
Obsoletes:      plasma5-addons < %{version}
Obsoletes:      plasma5-addons-lang < %{version}

%description
Additional plasmoids from upstream for use on the Plasma workspace.

%package devel
Summary:        Additional plasmoid widgets - development files
Requires:       kdeplasma6-addons = %{version}
Conflicts:      plasma5-addons-devel

%description devel
This package contains development files to develop additional widgets for
the Plasma desktop.

%lang_package

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%cmake_kf6

%kf6_build

%install
%kf6_install

%find_lang %{name} --all-name

%ldconfig_scriptlets

%files
%license LICENSES/*
%{_kf6_appstreamdir}/*.xml
%{_kf6_dbuspolicydir}/org.kde.kameleonhelper.conf
%{_kf6_debugdir}/kdeplasma-addons.categories
%ifarch x86_64 aarch64 riscv64
%{_kf6_iconsdir}/hicolor/scalable/apps/accessories-dictionary.svgz
%endif
%{_kf6_iconsdir}/hicolor/scalable/apps/fifteenpuzzle.svgz
%{_kf6_knsrcfilesdir}/comic.knsrc
%{_kf6_libdir}/libplasmapotdprovidercore.so.*
%{_kf6_libexecdir}/kauth/kameleonhelper
%{_kf6_notificationsdir}/plasma_applet_timer.notifyrc
%{_kf6_plasmadir}/desktoptheme/
%{_kf6_plasmadir}/plasmoids/
%{_kf6_plasmadir}/wallpapers/
%{_kf6_plugindir}/kf6/kded/kameleon.so
%dir %{_kf6_plugindir}/kf6/krunner
%{_kf6_plugindir}/kf6/krunner/*
%dir %{_kf6_plugindir}/kf6/packagestructure
%{_kf6_plugindir}/kf6/packagestructure/plasma_comic.so
%dir %{_kf6_plugindir}/kwin
%dir %{_kf6_plugindir}/kwin/effects
%dir %{_kf6_plugindir}/kwin/effects/configs
%{_kf6_plugindir}/kwin/effects/configs/kwin_cube_config.so
%{_kf6_plugindir}/plasma/applets/*
%{_kf6_plugindir}/plasmacalendarplugins/
%{_kf6_plugindir}/potd/
%{_kf6_qmldir}/org/kde/plasma/*
%{_kf6_qmldir}/org/kde/plasmacalendar/
%{_kf6_sharedir}/dbus-1/system-services/org.kde.kameleonhelper.service
%{_kf6_sharedir}/kwin/
%{_kf6_sharedir}/polkit-1/actions/org.kde.kameleonhelper.policy

%files devel
%dir %{_includedir}/plasma
%{_includedir}/plasma/potdprovider/
%{_kf6_cmakedir}/PlasmaPotdProvider/
%{_kf6_libdir}/libplasmapotdprovidercore.so
%{_kf6_sharedir}/kdevappwizard/templates/plasmapotdprovider.tar.bz2

%files lang -f %{name}.lang

%changelog
* Tue Dec 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.5:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.5
- Changes since 6.2.4:
  * update version for new release
  * Fixed issue that title was Info. And Author was not correct when a more than one () around text were used.
  * applets/userswitcher: Fit dialog height to content
  * update version for new release
* Tue Nov 26 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.4:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.4
- Changes since 6.2.3:
  * update version for new release
* Tue Nov  5 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.3:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.3
- Changes since 6.2.2:
  * update version for new release
  * applets/userswitcher: fix showing other logged-in users' avatars
* Tue Oct 22 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.2
- Changes since 6.2.1:
  * update version for new release
* Tue Oct 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.1
- Changes since 6.2.0:
  * update version for new release
  * applets/webbrowser: fix selecting "Fixed Scale"
* Sat Oct  5 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.0:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.0
- Changes since 6.1.90:
  * update version for new release
  * runners/converter: Fix thread affinity of currency update timer (kde#488713)
  * kameleon: sync config after writing entry (kde#493262)
* Tue Sep 17 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.90:
  * New feature release
  * For more details see https://kde.org/announcements/plasma/6/6.1.90
- Too many changes to list here
* Tue Sep 10 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.5:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.5
- Changes since 6.1.4:
  * update version for new release
* Tue Aug  6 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.4:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.4
- Changes since 6.1.3:
  * update version for new release
* Tue Jul 16 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.3:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.3
- Changes since 6.1.2:
  * update version for new release
* Wed Jul 10 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Enable the kameleon kded, service got whitelisted (boo#1226306)
* Tue Jul  2 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.2
- Changes since 6.1.1:
  * update version for new release
* Tue Jun 25 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.1
- Changes since 6.1.0:
  * update version for new release
  * effects/cube: reference main delegate (kde#488654)
  * update version for new release
* Thu Jun 13 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.0:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.0
- Changes since 6.0.90:
  * update version for new release
  * Fix middle click and tooltip
  * applets/weather: Show placeholder when there's no Forecast data
* Sat May 25 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.90:
  * New feature release
  * For more details see https://kde.org/announcements/plasma/6/6.0.90
- Too many changes to list here
* Wed May 22 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.5:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.5
- Changes since 6.0.4:
  * update version for new release
  * alternatecalendar: respect numbering system from libicu (kde#485373)
  * wallpapers/potd: fix dragging preview image in Qt6.7
* Wed Apr 17 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.4:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.4
- Changes since 6.0.3:
  * update version for new release
  * Fix clock tooltips not being localized
  * update version for new release
* Tue Mar 26 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.3:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.3
- Changes since 6.0.2:
  * update version for new release
  * wallpapers/potd: check network information backend is available before querying capabilities
  * update version for new release
  * applets/weather: remove invalid bindings on Layout properties
  * Mark QtQuick3D as a runtime dependency
* Wed Mar 13 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.2
- Changes since 6.0.1:
  * update version for new release
  * runners/converter: start timer in main thread
  * kdeplasma-addons: add Website to metadata to fix appstreamtest
  * update version for new release
* Wed Mar  6 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.1
- Changes since 6.0.0:
  * update version for new release
  * kwin/effects/cube: Bump clipFar plane (kde#482022)
  * kwin/effects/cube: Improve natural scrolling handling
  * kwin/effects/cube: Invert scroll direction (kde#482003)
  * applets/colorpicker: disable resizing color chooser window
* Mon Mar  4 2024 Christophe Marin <christophe@krop.fr>
- Add Provides/Obsoletes to replace Plasma 5
* Wed Feb 21 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.0:
  * New bugfix release
  * Release announcement not available yet
- Changes since 5.93.0:
  * update version for new release
  * wallpapers/image: make the last wallpaper stay longer during transition
  * wallpapers/potd: cleanup wallpapers when they go out of view
  * Add missing import (kde#480906)
  * applets/notes: use Plasma styling for as much as possible
  * [applets/keyboardindicator] hide icon when inactive
  * update version for new release
* Wed Jan 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.93.0 (6.0 RC 2):
  * New bugfix release
  * See https://kde.org/announcements/megarelease/6/rc2/ for details
- Changes since 5.92.0:
  * RC1 version
  * add a version for dependencies so it does not break CI https://invent.kde.org/plasma/bluedevil/-/merge_requests/156
  * applets/weather: Fix spacing on forecast view
  * Give the focus directly to the TextEdit component of the calculator (kde#479642)
* Mon Jan 22 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.92.0 (6.0 RC 1)
  * For more details please see:
    https://kde.org/announcements/megarelease/6/rc1/
* Mon Jul 10 2023 Christophe Marin <christophe@krop.fr>
- Init kdeplasma6-addons
